pub struct CreateBackup;Trait Implementations
Sourceimpl Archive for CreateBackup
impl Archive for CreateBackup
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedCreateBackup
type Archived = ArchivedCreateBackup
The archived representation of this type. Read more
Sourcetype Resolver = CreateBackupResolver
type Resolver = CreateBackupResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for CreateBackup
impl BlockingArchive for CreateBackup
Sourceimpl Debug for CreateBackup
impl Debug for CreateBackup
Sourceimpl<__D: Fallible + ?Sized> Deserialize<CreateBackup, __D> for Archived<CreateBackup>
impl<__D: Fallible + ?Sized> Deserialize<CreateBackup, __D> for Archived<CreateBackup>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<CreateBackup, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<CreateBackup, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for CreateBackup
impl MessageId for CreateBackup