pub struct CreateBackupFile {
pub backup_path: String,
pub location: Location,
}Fields
backup_path: Stringlocation: LocationTrait Implementations
Sourceimpl Archive for CreateBackupFilewhere
String: Archive,
Location: Archive,
impl Archive for CreateBackupFilewhere
String: Archive,
Location: Archive,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedCreateBackupFile
type Archived = ArchivedCreateBackupFile
The archived representation of this type. Read more
Sourcetype Resolver = CreateBackupFileResolver
type Resolver = CreateBackupFileResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for CreateBackupFile
impl BlockingArchive for CreateBackupFile
Sourceimpl Debug for CreateBackupFile
impl Debug for CreateBackupFile
Sourceimpl<__D: Fallible + ?Sized> Deserialize<CreateBackupFile, __D> for Archived<CreateBackupFile>
impl<__D: Fallible + ?Sized> Deserialize<CreateBackupFile, __D> for Archived<CreateBackupFile>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<CreateBackupFile, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<CreateBackupFile, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for CreateBackupFile
impl MessageId for CreateBackupFile
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for CreateBackupFilewhere
String: Serialize<__S>,
Location: Serialize<__S>,
impl<__S: Fallible + ?Sized> Serialize<__S> for CreateBackupFilewhere
String: Serialize<__S>,
Location: Serialize<__S>,