pub struct SubscribeRestoreProgress;Trait Implementations
Sourceimpl Archive for SubscribeRestoreProgress
impl Archive for SubscribeRestoreProgress
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedSubscribeRestoreProgress
type Archived = ArchivedSubscribeRestoreProgress
The archived representation of this type. Read more
Sourcetype Resolver = SubscribeRestoreProgressResolver
type Resolver = SubscribeRestoreProgressResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl ArchiveSubscription for SubscribeRestoreProgress
impl ArchiveSubscription for SubscribeRestoreProgress
Sourceimpl Debug for SubscribeRestoreProgress
impl Debug for SubscribeRestoreProgress
Sourceimpl<__D: Fallible + ?Sized> Deserialize<SubscribeRestoreProgress, __D> for Archived<SubscribeRestoreProgress>
impl<__D: Fallible + ?Sized> Deserialize<SubscribeRestoreProgress, __D> for Archived<SubscribeRestoreProgress>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<SubscribeRestoreProgress, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<SubscribeRestoreProgress, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for SubscribeRestoreProgress
impl MessageId for SubscribeRestoreProgress